using UnityEngine;

public class Bullet : MonoBehaviour {

    [SerializeField] private LayerMask _groundLayer;
    private Vector3 _startDirection;
    public SpriteRenderer SpriteRenderer;
    private GameObject _parentGameObject;
    private const float _speed = 10.0F;
    private const float _rotationSpeed = 3F;

    public GameObject Parent { set => _parentGameObject = value; get => _parentGameObject; }

    public Vector3 Direction { set => _startDirection = value; }

    public Color Color { set => SpriteRenderer.color = value; }

    private void Awake() => SpriteRenderer = GetComponentInChildren<SpriteRenderer>();

    private void Start() => Destroy(gameObject, 2F);

    private void Update() {
        transform.position = Vector3.MoveTowards(transform.position,
            transform.position + _startDirection,
            _speed * Time.deltaTime);
        transform.Rotate(0, 0, _rotationSpeed);
    }

    private void OnTriggerEnter2D(Collider2D collider) {
        if (collider.TryGetComponent(out EnemiesController unit) && unit.gameObject != _parentGameObject) {
            Destroy(gameObject);
        }
        if (collider.TryGetComponent(out Player player) && player.gameObject != _parentGameObject) {
            Destroy(gameObject);
        }
        Collider2D[] collider2D = Physics2D.OverlapCircleAll(transform.position, 0.1f, _groundLayer);
        for (int i = 0; i < collider2D.Length; i++) {
            if (collider2D[i].gameObject != gameObject) {
                Destroy(gameObject);
            }
        }
    }
}