using UnityEngine;

public class EagleController : EnemiesController {
    [SerializeField] private Transform _patrollingPoint;
    private float _speed = 2F;
    private const float _chaseStopDistance = 4f;
    private const int _positionOfPatrolling = 5;
    private bool _neutralState = false;
    private bool _angryState = false;
    private bool _returnState = false;
    private bool _facingRight = false;

    protected override void Start() => base.Start();

    protected void Update() {
        if (_JumpedOn) return;
        StateControl();
        StateMoveSpeed();
    }

    private void StateControl() {
        if (Vector2.Distance(transform.position, _patrollingPoint.position) < _positionOfPatrolling && _angryState == false) {
            _neutralState = true;
        }
        if (Vector2.Distance(transform.position, Target.position) < _chaseStopDistance) {
            _angryState = true;
            _neutralState = false;
            _returnState = false;
        }
        if (Vector2.Distance(transform.position, Target.position) > _chaseStopDistance) {
            _returnState = true;
            _angryState = false;
        }
    }

    private void StateMoveSpeed() {
        if (_neutralState) {
            _speed = 2F;
            Neutral();
        } else if (_angryState) {
            _speed = 3.5F;
            Angry();
        } else if (_returnState) {
            _speed = 3F;
            Return();
        }
    }

    private void Neutral() {
        if (transform.position.x > _patrollingPoint.position.x + _positionOfPatrolling) _facingRight = false;
        else if (transform.position.x < _patrollingPoint.position.x - _positionOfPatrolling) _facingRight = true;
        if (_facingRight) {
            transform.position = MoveSpeed(transform.position.x, transform.position.y, _speed);
            _SpriteRenderer.flipX = Mathf.Abs(transform.position.x) > 0.0F;
        } else {
            transform.position = MoveSpeed(transform.position.x, transform.position.y, -_speed);
            _SpriteRenderer.flipX = Mathf.Abs(transform.position.x) < 0.0F;
        }
    }

    private Vector2 MoveSpeed(float x, float y, float speed) => new(x + speed * Time.deltaTime, y);

    private void Angry() => State(Target);

    private void Return() => State(_patrollingPoint);

    private void Facing(Transform gameObject, Transform target) {
        if (target.position.x > gameObject.position.x) _SpriteRenderer.flipX = true;
        else _SpriteRenderer.flipX = false;
    }

    private void State(Transform target) {
        transform.position = Vector2.MoveTowards(transform.position, target.position, _speed * Time.deltaTime);
        Facing(transform, Target);
    }
}