using UnityEngine;

public class EnemiesController : MonoBehaviour
{
    protected Animator _Animator;
    protected AudioSource ExplosionSound;
    protected bool _JumpedOn;
    protected Rigidbody2D _RigidBody2D;
    protected Collider2D _Collider2D;
    protected Transform Target;
    protected SpriteRenderer _SpriteRenderer;

    protected virtual void Start()
    {
        Target = Player.SingletonInstance.transform;
        ExplosionSound = GetComponent<AudioSource>();
        _RigidBody2D = GetComponent<Rigidbody2D>();
        _Collider2D = GetComponent<Collider2D>();
        _Animator = GetComponent<Animator>();
        _SpriteRenderer = GetComponent<SpriteRenderer>();
    }

    protected virtual void Destroying() => Destroy(this.gameObject);

    public virtual void JumpedOn()
    {
        _Animator.SetTrigger("Death");
        _RigidBody2D.constraints = RigidbodyConstraints2D.FreezeAll;
        ExplosionSound.Play();
        _Collider2D.enabled = false;
        _JumpedOn = true;
    }

    protected virtual void OnTriggerEnter2D(Collider2D collision)
    {
        if (collision.TryGetComponent(out Bullet bullet) && bullet.Parent.TryGetComponent(out Player player)) JumpedOn();
    }
}