using System.IO;
using UnityEngine;
using System.Collections;
using TMPro;

public class SaveSystem : MonoBehaviour {

    [SerializeField] private TextMeshProUGUI _saveText;
    private string _savePath;
    private Player _player;
    public bool CanSave;
    private AudioSource _saveSound;
    private SaveData _savedData = new();

    public static SaveSystem SingletonInstance { get; private set; }

    private void Awake() => SingletonInstance = this;

    private void Start() {
        Cursor.visible = false;
        CanSave = true;
        _player = Player.SingletonInstance;
        _savePath = Application.persistentDataPath + "/SaveGame.data";
        _saveSound = GetComponent<AudioSource>();
    }

    private void Save() {
        _savedData.Position = _player.gameObject.transform.position;
        _savedData.HP = _player.HitPoint;
        _savedData.Ammoes = _player.Ammoes;
        string jsonString = JsonUtility.ToJson(_savedData);
        File.WriteAllText(_savePath, jsonString);
    }

    public void Load() {
        if (File.Exists(_savePath)) {
            string fileData = File.ReadAllText(_savePath);
            SaveData dataToSave = JsonUtility.FromJson<SaveData>(fileData);
            _player.transform.position = dataToSave.Position;
            _player.HitPoint = dataToSave.HP;
            _player.Ammoes = dataToSave.Ammoes;
        }
    }

    private void OnTriggerEnter2D(Collider2D collision) {
        if (collision.TryGetComponent(out Player player) && CanSave) {
            _saveText.enabled = true;
            _saveSound.Play();
            Save();
            CanSave = false;
            StartCoroutine(TextRemove());
        }
    }

    private IEnumerator TextRemove() {
        yield return new WaitForSeconds(3f);
        _saveText.enabled = false;
    }

    [System.Serializable]
    public class SaveData {
        public Vector2 Position;
        public int HP;
        public int Ammoes;
    }
}